@@ -326,7 +326,7 @@ void MainWindow::initActions()
   actionCollection()->addAction(action->objectName(), action);
   action->setToolTip(i18n("Open a saved skin..."));
 
-  m_rfa = KStandardGameAction::loadRecent (this, SLOT(slotURLSelected(KUrl)), this);
+  m_rfa = KStandardGameAction::loadRecent (this, SLOT(slotURLSelected(QUrl)), this);
   actionCollection()->addAction(m_rfa->objectName(), m_rfa);
   m_rfa->setText(i18n("Load &Recent"));
   m_rfa->setToolTip(i18n("Open a recently saved skin..."));
@@ -384,11 +384,8 @@ void MainWindow::slotOpenSkin(const QString& dir)
   m_skinDefWidget->continentslist->clear();
   m_skinDefWidget->goalslist->clear();
   
-  if (m_onu != 0)
-  {
-    delete m_onu;
-  }
-  m_onu = new ONU(skinDir);
+  delete m_onu;
+  m_onu = new ONU(skinDir, this);
 
   m_skinDefWidget->fontrequester->setFont(m_onu->foregroundFont());
   m_skinDefWidget->fgcolorbutton->setColor(m_onu->foregroundColor());
@@ -1314,6 +1311,7 @@ void MainWindow::slotNewCountry()
 void MainWindow::slotDeleteCountry()
 {
   if (m_onu == 0) return;
+  if (!m_skinDefWidget->countrieslist->currentItem()) return;
   qCDebug(KSIRKSKINEDITOR_LOG);
   int answer = KMessageBox::warningContinueCancel(this, i18n("Do you really want to delete country '%1'?", m_skinDefWidget->countrieslist->currentItem()->text()), i18n("Really delete country?"));
   if (answer == KMessageBox::Cancel)
@@ -1342,6 +1340,7 @@ void MainWindow::slotNewContinent()
 void MainWindow::slotDeleteContinent()
 {
   if (m_onu == 0) return;
+  if (!m_skinDefWidget->continentslist->currentItem()) return;
   qCDebug(KSIRKSKINEDITOR_LOG);
   int answer = KMessageBox::warningContinueCancel(this, i18n("Do you really want to delete continent '%1'?", m_skinDefWidget->continentslist->currentItem()->text()), i18n("Really delete continent?"));
   if (answer == KMessageBox::Cancel)
@@ -1890,6 +1889,7 @@ void MainWindow::slotNewGoal()
 void MainWindow::slotDeleteGoal()
 {
   if (m_onu == 0) return;
+  if (!m_skinDefWidget->goalslist->currentItem()) return;
   qCDebug(KSIRKSKINEDITOR_LOG);
   int answer = KMessageBox::warningContinueCancel(this, i18n("Do you really want to delete goal '%1'?", m_skinDefWidget->goalslist->currentItem()->text()), i18n("Really delete goal?"));
   if (answer == KMessageBox::Cancel)
@@ -1958,6 +1958,7 @@ void MainWindow::slotNewNationality()
 void MainWindow::slotDeleteNationality()
 {
   if (m_onu == 0) return;
+  if (!m_skinDefWidget->nationalitieslist->currentItem()) return;
   qCDebug(KSIRKSKINEDITOR_LOG);
   int answer = KMessageBox::warningContinueCancel(this, i18n("Do you really want to delete nationality '%1'?", m_skinDefWidget->nationalitieslist->currentItem()->text()), i18n("Really delete nationality?"));
   if (answer == KMessageBox::Cancel)
@@ -2115,7 +2116,6 @@ void MainWindow::slotCavalryxValueChanged(int v)
     m_onu->setDirty();
   }
 }
-
 void MainWindow::slotCavalryyValueChanged(int v)
 {
   qCDebug(KSIRKSKINEDITOR_LOG);
